@@ -1,27 +1,15 @@
 <?php
-/**
- * block.t.php - Smarty gettext block plugin
+
+/*
+ * This file is part of the smarty-gettext package.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * @copyright (c) Elan Ruusamäe
+ * @license GNU Lesser General Public License, version 2.1 or any later
+ * @see https://github.com/smarty-gettext/smarty-gettext/
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- * @package   smarty-gettext
- * @link      https://github.com/smarty-gettext/smarty-gettext
- * @author    Sagi Bashari <sagi@boom.org.il>
- * @author    Elan Ruusamäe <glen@delfi.ee>
- * @copyright 2004-2005 Sagi Bashari
- * @copyright 2010-2015 Elan Ruusamäe
+ * For the full copyright and license information,
+ * please see the LICENSE and AUTHORS files
+ * that were distributed with this source code.
  */
 
 /**
@@ -71,7 +59,7 @@ function smarty_gettext_strarg($str/*, $varargs... */) {
  *
  * @param array $params
  * @param string $text
- * @link http://www.smarty.net/docs/en/plugins.block.functions.tpl
+ * @see http://www.smarty.net/docs/en/plugins.block.functions.tpl
  * @return string
  */
 function smarty_block_t($params, $text) {
@@ -118,15 +106,23 @@ function smarty_block_t($params, $text) {
 	// use plural if required parameters are set
 	if (isset($count) && isset($plural)) {
 		// use specified textdomain if available
-		if (isset($domain)) {
+		if (isset($domain) && isset($context)) {
+			$text = dnpgettext($domain, $context, $text, $plural, $count);
+		} elseif (isset($domain)) {
 			$text = dngettext($domain, $text, $plural, $count);
+		} elseif(isset($context)) {
+			$text = npgettext($context, $text, $plural, $count);
 		} else {
 			$text = ngettext($text, $plural, $count);
 		}
 	} else {
 		// use specified textdomain if available
-		if (isset($domain)) {
+		if (isset($domain) && isset($context)) {
+			$text = dpgettext($domain, $context, $text);
+		} elseif (isset($domain)) {
 			$text = dgettext($domain, $text);
+		} elseif (isset($context)) {
+			$text = pgettext($context, $text);
 		} else {
 			$text = gettext($text);
 		}
