@@ -1,22 +1,21 @@
 #!/usr/bin/env php
 <?php
+
+/*
+ * This file is part of the smarty-gettext package.
+ *
+ * @copyright (c) Elan Ruusamäe
+ * @license GNU Lesser General Public License, version 2.1 or any later
+ * @see https://github.com/smarty-gettext/smarty-gettext/
+ *
+ * For the full copyright and license information,
+ * please see the LICENSE and AUTHORS files
+ * that were distributed with this source code.
+ */
+
 /**
  * tsmarty2c.php - rips gettext strings from smarty template
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
  * This commandline script rips gettext strings from smarty file,
  * and prints them to stdout in already gettext encoded format, which you can
  * later manipulate with standard gettext tools.
@@ -24,14 +23,13 @@
  * Usage:
  * ./tsmarty2c.php -o template.pot <filename or directory> <file2> <..>
  *
- * If a parameter is a directory, the template files within will be parsed.
+ * Extract gettext strings of default (empty) domain only:
+ * ./tsmarty2c.php -d -o default.pot <filename or directory> <file2> <..>
  *
- * @package   smarty-gettext
- * @link      https://github.com/smarty-gettext/smarty-gettext/
- * @author    Sagi Bashari <sagi@boom.org.il>
- * @author    Elan Ruusamäe <glen@delfi.ee>
- * @copyright 2004-2005 Sagi Bashari
- * @copyright 2010-2015 Elan Ruusamäe
+ * Extract gettext strings of domain "custom" only (e.g {t domain="custom"}...):
+ * ./tsmarty2c.php -d=custom -o custom.pot <filename or directory> <file2> <..>
+ *
+ * If a parameter is a directory, the template files within will be parsed.
  */
 
 // smarty open tag
@@ -115,6 +113,17 @@ function do_file($outfile, $file) {
 	for ($i = 0; $i < count($matches[0]); $i++) {
 		$msg_ctxt = null;
 		$plural = null;
+
+		if (defined('DOMAIN')) {
+			if (preg_match('/domain\s*=\s*["\']?\s*(.[^\"\']*)\s*["\']?/', $matches[2][$i][0], $match)) {
+				if($match[1] != DOMAIN) {
+					continue; // Skip strings with domain, if not matching domain to extract
+				}
+			} elseif (DOMAIN != '') {
+				continue; // Skip strings without domain, if domain to extract is not default/empty
+			}
+		}
+
 		if (preg_match('/context\s*=\s*["\']?\s*(.[^\"\']*)\s*["\']?/', $matches[2][$i][0], $match)) {
 			$msg_ctxt = $match[1];
 		}
@@ -220,7 +229,7 @@ if ('cli' != php_sapi_name()) {
 
 define('PROGRAM', basename(array_shift($argv)));
 define('TMPDIR', sys_get_temp_dir());
-$opt = getopt('o:');
+$opt = getopt('o:d::');
 $outfile = isset($opt['o']) ? $opt['o'] : tempnam(TMPDIR, 'tsmarty2c');
 
 // remove -o FILENAME from $argv.
@@ -236,6 +245,18 @@ if (isset($opt['o'])) {
 	}
 }
 
+// remove -d DOMAIN from $argv.
+if (isset($opt['d'])) {
+	define('DOMAIN', trim($opt['d']));
+	foreach ($argv as $i => $v) {
+		if (!preg_match('#^-d=?#',$v)) {
+			continue;
+		}
+		unset($argv[$i]);
+		break;
+	}
+}
+
 // initialize output
 file_put_contents($outfile, MSGID_HEADER);
 
